include(CheckIncludeFile)
include(CheckFunctionExists)

check_include_file("dlfcn.h" HAVE_DLFCN_H)
check_include_file("fcntl.h" HAVE_FCNTL_H)
check_include_file("inttypes.h" HAVE_INTTYPES_H)
check_include_file("memory.h" HAVE_MEMORY_H)
check_include_file("stdint.h" HAVE_STDINT_H)
check_include_file("stdlib.h" HAVE_STDLIB_H)
check_include_file("strings.h" HAVE_STRINGS_H)
check_include_file("string.h" HAVE_STRING_H)
check_include_file("sys/capability.h" HAVE_SYS_CAPABILITY_H)
check_include_file("sys/mman.h" HAVE_SYS_MMAN_H)
check_include_file("sys/msg.h" HAVE_SYS_MSG_H)
check_include_file("sys/select.h" HAVE_SYS_SELECT_H)
check_include_file("sys/socket.h" HAVE_SYS_SOCKET_H)
check_include_file("sys/stat.h" HAVE_SYS_STAT_H)
check_include_file("sys/types.h" HAVE_SYS_TYPES_H)
check_include_file("unistd.h" HAVE_UNISTD_H)
check_include_file("winsock2.h" HAVE_WINSOCK2_H)
check_include_file("ws2tcpip.h" HAVE_WS2TCPIP_H)

if(WIN32)
	set(HAVE_DOSISH_SYSTEM 1)
    set(HAVE_W32_SYSTEM 1)
    set(HAVE_DRIVE_LETTERS 1)
    if(WINCE)
        set(HAVE_W32CE_SYSTEM 1)
        set(USE_RNDW32CE 1)
        if(WCECOMPAT_FOUND)
            set(HAVE_WCECOMPAT 1)
        endif(WCECOMPAT_FOUND)
    else(WINCE)
        set(USE_RNDW32 1)
    endif(WINCE)
    if(MSVC)
        set(inline "__inline")
    else(MSVC)
        set(inline "__inline__")
    endif(MSVC)
endif(WIN32)


#/* Define if you don't want the default EGD socket name. For details see
#   cipher/rndegd.c */
#undef EGD_SOCKET_NAME
#/* Enable support for the PadLock engine. */
#undef ENABLE_PADLOCK_SUPPORT

#/* The default error source for libgcrypt. */
set(GPG_ERR_SOURCE_DEFAULT 1)

check_function_exists(atexit HAVE_ATEXIT)
check_function_exists(clock HAVE_CLOCK)
check_function_exists(clock_gettime HAVE_CLOCK_GETTIME)
check_function_exists(fcntl HAVE_FCNTL)
check_function_exists(ftruncate HAVE_FTRUNCATE)
check_function_exists(gethrtime HAVE_GETHRTIME)
check_function_exists(getpagesize HAVE_GETPAGESIZE)
check_function_exists(getpid HAVE_GETPID)
check_function_exists(getrusage HAVE_GETRUSAGE)
check_function_exists(gettimeofday HAVE_GETTIMEOFDAY)
check_function_exists(memmove HAVE_MEMMOVE)
check_function_exists(mmap HAVE_MMAP)
check_function_exists(raise HAVE_RAISE)
check_function_exists(rand HAVE_RAND)
check_function_exists(stpcpy HAVE_STPCPY)
check_function_exists(_stricmp HAVE_STRCASECMP)
check_function_exists(strerror HAVE_STRERROR)
check_function_exists(_stricmp HAVE_STRICMP)
check_function_exists(strtoul HAVE_STRTOUL)
check_function_exists(sysconf HAVE_SYSCONF)
check_function_exists(syslog HAVE_SYSLOG)
check_function_exists(vprintf HAVE_VPRINTF)
check_function_exists(wait4 HAVE_WAIT4)
check_function_exists(waitpid HAVE_WAITPID)

#/* Defined if a `byte' is typedef'd */
#undef HAVE_BYTE_TYPEDEF
#/* Defined if a `ulong' is typedef'd */
#undef HAVE_ULONG_TYPEDEF
#/* Defined if a `ushort' is typedef'd */
#undef HAVE_USHORT_TYPEDEF
#/* Defined if a `u16' is typedef'd */
#undef HAVE_U16_TYPEDEF
#/* Defined if a `u32' is typedef'd */
#undef HAVE_U32_TYPEDEF

set(LIBGCRYPT_CIPHERS "")

if(USE_ARCFOUR)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS}arcfour")
endif(USE_ARCFOUR)
if(USE_BLOWFISH)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} blowfish")
endif(USE_BLOWFISH)
if(USE_CAST5)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} cast5")
endif(USE_CAST5)
if(USE_DES)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} des")
endif(USE_DES)
if(USE_AES)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} aes")
endif(USE_AES)
if(USE_TWOFISH)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} twofish")
endif(USE_TWOFISH)
if(USE_SERPENT)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} serpent")
endif(USE_SERPENT)
if(USE_RFC2268)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} rfc2268")
endif(USE_RFC2268)
if(USE_SEED)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} seed")
endif(USE_SEED)
if(USE_CAMELLIA)
    set(LIBGCRYPT_CIPHERS "${LIBGCRYPT_CIPHERS} camellia")
endif(USE_CAMELLIA)

#/* List of available digest algorithms */
set(LIBGCRYPT_DIGESTS "rmd160 sha1")
set(USE_SHA1 1)
set(USE_RMD160 1)
if(USE_CRC)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} crc")
endif(USE_CRC)
if(USE_MD4)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} md4")
endif(USE_MD4)
if(USE_MD5)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} md5")
endif(USE_MD5)
if(USE_SHA256)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} sha256")
endif(USE_SHA256)
if(USE_SHA512)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} sha512")
endif(USE_SHA512)
if(USE_TIGER)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} tiger")
endif(USE_TIGER)
if(USE_WHIRLPOOL)
    set(LIBGCRYPT_DIGESTS "${LIBGCRYPT_DIGESTS} whirlpool")
endif(USE_WHIRLPOOL)

#/* List of available public key cipher algorithms */
set(LIBGCRYPT_PUBKEY_CIPHERS "")
if(USE_DSA)
    set(LIBGCRYPT_PUBKEY_CIPHERS "${LIBGCRYPT_PUBKEY_CIPHERS}dsa")
endif(USE_DSA)
if(USE_RSA)
    set(LIBGCRYPT_PUBKEY_CIPHERS "${LIBGCRYPT_PUBKEY_CIPHERS} rsa")
endif(USE_RSA)
if(USE_ELGAMAL)
    set(LIBGCRYPT_PUBKEY_CIPHERS "${LIBGCRYPT_PUBKEY_CIPHERS} elgamal")
endif(USE_ELGAMAL)
if(USE_ECC)
    set(LIBGCRYPT_PUBKEY_CIPHERS "${LIBGCRYPT_PUBKEY_CIPHERS} ecc")
endif(USE_ECC)

#/* Name of this package */
set(PACKAGE "libgcrypt")
#/* Version of this package */
set(VERSION "\"${GCRYPT_VERSION}\"")
#/* Define to the address where bug reports for this package should be sent. */
set(PACKAGE_BUGREPORT "\"kde-windows@kde.org\"")
#/* Define to the full name of this package. */
#undef PACKAGE_NAME
#/* Define to the full name and version of this package. */
#undef PACKAGE_STRING
#/* Define to the one symbol short name of this package. */
#undef PACKAGE_TARNAME
#/* Define to the version of this package. */
set(PACKAGE_VERSION "\"${PACKAGE}-${GCRYPT_VERSION}\"")
#/* A human readable text with the name of the OS */
#undef PRINTABLE_OS_NAME

include(CheckTypeSize)
check_type_size("uintptr_t" UINTPTR_T)
if(HAVE_UINTPTR_T)
    set(HAVE_UINTPTR_T 1)
else(HAVE_UINTPTR_T)
    set(HAVE_UINTPTR_T 0)
endif(HAVE_UINTPTR_T)
check_type_size("unsigned int" SIZEOF_UNSIGNED_INT)
check_type_size("unsigned long" SIZEOF_UNSIGNED_LONG)
check_type_size("unsigned long long" SIZEOF_UNSIGNED_LONG_LONG)
check_type_size("unsigned short" SIZEOF_UNSIGNED_SHORT)

#/* Define to support the experimental random daemon */
#undef USE_RANDOM_DAEMON
#/* define if capabilities should be used */
#undef USE_CAPABILITIES

#set(pid_t "int")
#/* Define to `unsigned int' if <sys/types.h> does not define. */
#set(size_t "unsigned int")
#/* type to use in place of socklen_t if not defined */
#undef socklen_t
#/* Define to the type of an unsigned integer type wide enough to hold a
#   pointer, if such a type exists, and if the system does not define it. */
#undef uintptr_t

if(HAVE_SOCKLEN_T)
    set(FALLBACK_SOCKLEN_T "typedef socklen_T gcry_socklen_t;")
else(HAVE_SOCKLEN_T)
    set(FALLBACK_SOCKLEN_T "typedef int gcry_socklen_t;")
endif(HAVE_SOCKLEN_T)

set(INSERT_SYS_SELECT_H "")

configure_file(config.h.cmake config.h)
configure_file(src/gcrypt.h.in gcrypt.h)
